==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Sad.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Sad extends GenericDPSObject {
    /**
     * SAD.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SAD.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * SAD.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SAD.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SAD.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SAD.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * SAD.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return SAD.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SAD.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Sad other = (Sad) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Sad.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Sad extends GenericDPSObject {
    /**
     * SAD.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SAD.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * SAD.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SAD.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SAD.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SAD.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * SAD.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return SAD.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SAD.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Sad other = (Sad) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}
